from gemini_framework.abstract.unit_module_abstract import UnitModuleAbstract
from gemini_model.pump.esp import ESP


class CalculateMeasuredPumpHead(UnitModuleAbstract):

    def __init__(self, unit):
        super().__init__(unit)

        self.model = ESP()

        self.link_input('measured', 'esp_inlet_pressure')
        self.link_input('calculated', 'esp_discharge_pressure')
        self.link_output('calculated', 'esp_measured_head')

    def step(self, loop):
        self.loop = loop
        self.loop.start_time = self.get_output_last_data_time('esp_measured_head')
        self.loop.compute_n_simulation()

        time, esp_intake = self.get_input_data('esp_inlet_pressure')
        time, esp_discharge = self.get_input_data('esp_discharge_pressure')

        esp_measured_head = []
        for ii in range(1, self.loop.n_step):
            try:
                esp_head = esp_discharge[ii] - esp_intake[ii]

                esp_measured_head.append(esp_head)
            except Exception as e:
                self.logger.warn("ERROR:" + repr(e))
                esp_measured_head.append(None)

        if esp_measured_head:
            self.write_output_data('esp_measured_head', time, esp_measured_head)
